.. fico documentation master file, created by
   sphinx-quickstart on Sun Dec 17 23:47:17 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Fico reference
======================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   source/modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
